<?php
/****************************************************************************
 * DRBImageGallery
 * http://www.dbscripts.net/imagegallery/
 * 
 * Copyright (c) 2007-2009 Don Barnes 
 ****************************************************************************/
 
$MAX_IMAGE_FILE_SIZE = 4000000;
 
function images_header($page_subtitle = "Image Management") {
	global $dbs_error;

	// Open database connection	
	if(db_connect() === FALSE) {
		die("Error connecting to database: " . htmlspecialchars_default(db_error()));
	}

	include_from_template('header.php');
	
	echo "<h2>" . htmlspecialchars_default($page_subtitle) . "</h2>\n";

	if(isset($dbs_error)) {
		echo "<p class=\"errorMessage\">" . htmlspecialchars_default($dbs_error) . "</p>";
	}

}

function show_images() {

	images_header();
	
	echo "<p>Please search for the images you would like to edit.</p>";
	
	image_query_form("Image Management Search", "queryimages");
	
	show_back_button();

	include_from_template('footer.php');
	
}

function query_images() {
	
	images_header();

	image_query_form("Image Management Search", "queryimages");
	
	echo("<h2>Search Results</h2>");
	
	image_details_table_from_query("queryimages");
	
	show_back_button();
	
	include_from_template('footer.php');
}

function upload_image() {
	global $dbs_error;
	global $IMAGE_FOLDER;
	global $THUMB_FOLDER;
	global $MAX_IMAGE_FILE_SIZE;

	// Confirm that a file was uploaded
	if(!isset($_FILES['imageFile']) || empty($_FILES['imageFile']['name'])) {
		$dbs_error = "No file was uploaded.";
		return FALSE;
	}
	
	$image_path = dirname(__FILE__) . '/../' . $IMAGE_FOLDER;
	$thumb_path = dirname(__FILE__) . '/../' . $THUMB_FOLDER;
	$upload_image_name = $_FILES['imageFile']['name'];
	$destination_file = $image_path . '/' . basename($upload_image_name);
	
	// Validate length of file name
	global $MAX_IMAGE_FILENAME_LENGTH;
	if(strlen($upload_image_name) > $MAX_IMAGE_FILENAME_LENGTH) {
		$dbs_error = "The name of this file is greater than the maximum length of " . htmlspecialchars_default("".$MAX_IMAGE_FILENAME_LENGTH) . ".";
		return FALSE; 
	}
	
	// Validate file type
	if(!is_image_file($destination_file)) {
		$dbs_error = "This file type is not supported.";
		return FALSE; 
	}
	
	// Validate file size
	$fileSize = $_FILES['imageFile']['size'];
	if($fileSize > $MAX_IMAGE_FILE_SIZE) {
		$dbs_error = "Uploaded image is larger than the maximum size of " . htmlspecialchars_default($MAX_IMAGE_FILE_SIZE) . " bytes";
		return FALSE;
	}
	if($fileSize <= 0) {
		$dbs_error = "Uploaded image has an invalid file size.";
		return FALSE;
	}
	
	// Confirm that this isn't a duplicate
	if(file_exists($destination_file)) {
		$dbs_error = "An image with this file name already exists in the gallery.";
		return FALSE;
	}
	
	// Move file to destination images folder
	if(move_uploaded_file($_FILES['imageFile']['tmp_name'], $destination_file)) {

    	// Add image record
    	if(add_new_image(basename($upload_image_name), $image_path, $thumb_path) === FALSE) {
    		return FALSE;
    	}
    	return db_insert_id();	// Return image ID
    	
	} else {
		
		// Move failed
		$dbs_error = "Unable to move uploaded image to destination folder: " . htmlspecialchars_default($destination_file);
		return FALSE;
		
	}
}

function show_upload_image() {
	global $MAX_IMAGE_FILE_SIZE;

	images_header("Upload Image");
	
?>

<form enctype="multipart/form-data" method="post" action=".">
<fieldset>
<legend>Upload Image</legend>
<p>
<input type="hidden" name="MAX_FILE_SIZE" value="<?php echo( htmlspecialchars_default($MAX_IMAGE_FILE_SIZE) ) ?>" />
<label for="imageFile">Image File:</label>
<input name="imageFile" id="imageFile" type="file" />
<?php image_nav_input(NULL, "uploadimage"); ?>
<input type="submit" value="Upload" class="submit" />
</p>
</fieldset>  
</form>
<?php

	show_back_button();
	
	include_from_template('footer.php');


	
}	

function show_image($image) {
	global $IMAGE_FOLDER;

	images_header();
	
	$thumb_url = getThumbURL($image['filename']);
	$img_url = getImageURL($image['filename']);
	global $MAX_IMAGE_NAME_LENGTH;
?>
<h2>Edit Image</h2>

<form method="post" action=".">
<fieldset>
<legend>Edit Image</legend>

<p id="editFormImageContainer">
<?php echo("<a href=\"{$img_url}\"><img src=\"{$thumb_url}\" alt=\"" 
	. htmlspecialchars_default($image['filename']) . "\" /></a><br />\n" . htmlspecialchars_default($image['filename']) . "\n"); ?>
</p>

<p>
<input type="hidden" name="imageId" id="imageId" value="<?php echo(htmlspecialchars_default($image['imageId'])); ?>" />
<label for="name">Name:</label>
<input type="text" name="name" id="name" maxlength="<?php echo(htmlspecialchars_default($MAX_IMAGE_NAME_LENGTH)); ?>" value="<?php echo(htmlspecialchars_default($image['name'])); ?>" /><br />
<label for="description">Description:</label>
<textarea cols="30" rows="4" name="description" id="description"><?php echo(htmlspecialchars_default($image['description'])); ?></textarea>
</p>
<?php image_nav_input(NULL, "saveimage"); ?>
<input type="submit" value="Save" class="submit" id="editFormImageButton" />
</fieldset>  
</form>

<h2>Image Attributes</h2>

<form method="post" action=".">
<fieldset>
<legend>Add Attribute Value</legend>
<p>
<input type="hidden" name="imageId" value="<?php echo(htmlspecialchars_default($image['imageId'])); ?>" />
<label for="attrImageId">Attribute:</label>

<?php
		echo("<select name=\"attributeId\" id=\"attributeId\" onchange=\"do_values()\">\n");
		echo("<option value=\"\"></option>\n");
		$res = find_attributes(null, "sequenceNum asc", null, null);
		if($res === FALSE) {
			global $dbs_error;
			die('Could not find attributes: ' . $dbs_error);
		}
		$javascript_array_buf = "";
		while( ($assoc = db_fetch($res)) !== FALSE ) {
			$optionValue = htmlspecialchars_default($assoc['attributeId']);
			$optionName = htmlspecialchars_default($assoc['name']);
			echo("<option value=\"{$optionValue}\">{$optionName}</option>\n");
			$javascript_array_buf .= "attr_values['{$optionValue}'] = new Array();\n";
		}
		echo("</select>\n");
		echo("<br />\n");
?>
<label for="valueId" id="valueIdLabel" style="display: none;">Value:</label>
<?php
	echo("<select name=\"valueId\" id=\"valueId\" style=\"display: none;\">\n");
	echo("<option value=\"\"></option>\n");
	echo("</select>\n");
?>

</p>
<?php image_nav_input(NULL, "saveimageattributevalue"); ?>
<input type="submit" value="Save" class="submit" />
</fieldset>  
</form>

<?php
	$res = find_values(null, "attributeId asc, value asc", null, null);
	if($res === FALSE) {
		global $dbs_error;
		die('Could not find attributes: ' . $dbs_error);
	}
?>
<script type="text/javascript">
//<![CDATA[
var attr_values = new Array();
<?php
	echo $javascript_array_buf;
	
	while( ($assoc = db_fetch($res)) !== FALSE ) {
		$attributeId = htmlspecialchars_default($assoc['attributeId']);
		$valueId = htmlspecialchars_default($assoc['valueId']);
		$value = rawurlencode($assoc['value']);
		echo("attr_values['$attributeId']['$valueId'] = '$value';\n");
	}

?>
function do_values() {
	var attributeId = document.getElementById("attributeId").value;
	var valueElement = document.getElementById("valueId");
	var valueIdLabelElement = document.getElementById("valueIdLabel");
	
	if(attributeId != null && attributeId.length > 0) {
		valueIdLabelElement.style.display = 'inline';
		valueElement.style.display = 'inline';	
		var the_values = attr_values[attributeId];
		if(the_values.length > 0) {
			valueElement.options.length = 0;
			valueElement[valueElement.options.length] = new Option("", ""); 
			for(valueId in the_values) {
				valueElement[valueElement.options.length] 
					= new Option(unescape(the_values[valueId]), valueId); 
			}
			return;
		}
	}
	valueElement.options.length = 0;	
	valueIdLabelElement.style.display = 'none';
	valueElement.style.display = 'none';
}
//]]>
</script> 

<?php

	image_attribute_value_table_by_imageId($image['imageId']);

	global $OFFSET_PARAM_NAME;
	
	image_nav_form("Back to Image Management Results", (isset($_REQUEST[$OFFSET_PARAM_NAME])?$_REQUEST[$OFFSET_PARAM_NAME]:NULL), "bottomPageNav", "queryimages");

	show_back_button();
	
	include_from_template('footer.php');

}
	
?>