<?php
/****************************************************************************
 * DRBImageGallery
 * http://www.dbscripts.net/imagegallery/
 * 
 * Copyright (c) 2007-2009 Don Barnes 
 ****************************************************************************/
 
$base_url = "./../";
require_once(dirname(__FILE__) . '/../includes/utils.php');
require_once(dirname(__FILE__) . '/../includes/db_utils.php');
require_once(dirname(__FILE__) . '/../includes/images.php');
require_once(dirname(__FILE__) . '/../includes/attributes.php');
require_once(dirname(__FILE__) . '/../includes/values.php');
require_once(dirname(__FILE__) . '/../admin/admin_panel.php');
require_once(dirname(__FILE__) . '/../admin/scan.php');
require_once(dirname(__FILE__) . '/../admin/images.php');
require_once(dirname(__FILE__) . '/../admin/attributes.php');
require_once(dirname(__FILE__) . '/../config.php');
require_once(dirname(__FILE__) . '/../strings.php');

// Confirm that application is fully installed
confirm_install();

// Start session
session_start();

// Check if logged in
if(!isset($_SESSION['username']) || !isset($_SESSION['admin'])) {
	
	// Redirect to login page
	relative_location('../login.php');
	exit();
	
}

// Check if admin
if($_SESSION['admin'] !== "TRUE") {
	
	// Redirect to home page
	relative_location('..');
	exit();

}

// Handle actions
if(isset($_REQUEST['action'])) {
	global $READ_ONLY_MODE;
	
	$action = $_REQUEST['action'];
	switch($action) {
		
		case "scan":
		
			do_scan();
			break;
			
		case "showimages":

			show_images();
			break;

		case "queryimages":

			query_images();
			break;
			
		case "showimage":
		
			db_connect();
			$image = find_image_by_id($_POST['imageId']);
			show_image($image);
			break;
			
		case "showimageupload":
		
			show_upload_image();
			break;
			
		case "uploadimage":
		
		    if($READ_ONLY_MODE === FALSE) {
		    	
		    	db_connect();
		    	$imageId = upload_image();
			    if($imageId !== FALSE) {
			    	
			    	// Show image
					$image = find_image_by_id($imageId);
					show_image($image);
			    	
			    } else {

			    	// There was an error adding the uploaded image
			    	show_upload_image();
			    	
			    }
			    
		    } else {
		    	
		    	global $dbs_error;
		    	$dbs_error = "This application is in read only mode.";
		    	show_upload_image();
		    	
		    }
			break;
			
		case "deleteimage":
		
			if($READ_ONLY_MODE === FALSE) {
				db_connect();
				$image = find_image_by_id($_POST['imageId']);
				remove_image($image);
			}
			
			// Return to query results
			query_images();
			break;
			
		case "saveimage":

			db_connect();

			// Update image
			if($READ_ONLY_MODE === FALSE) {
				$values = Array("name" => $_POST['name'], "description" => $_POST['description']);
				update_image($values, $_POST['imageId']);
			}

			// Show image page
			$image = find_image_by_id($_POST['imageId']);		
			show_image($image);
			break;
			
		case "saveimageattributevalue":

			db_connect();
			
			// Insert image attribute value
			if($READ_ONLY_MODE === FALSE) {
				$values = Array("imageId" => $_POST['imageId'], "attributeId" => $_POST['attributeId'], "valueId" => $_POST['valueId']);
				insert_image_attribute_value($values);
			}
			
			// Show image page
			$image = find_image_by_id($_POST['imageId']);
			show_image($image);
			break;
			
		case "deleteimageattributevalue":
			db_connect();
			
			// Delete image attribute value
			if($READ_ONLY_MODE === FALSE) {
				delete_image_attribute_value($_POST['imageId'], $_POST['attributeId'], $_POST['valueId']);
			}

			// Show image page			
			$image = find_image_by_id($_POST['imageId']);
			show_image($image);
			break;
			
		case "showattributes":
			
			show_attributes();
			break;
			
		case "showattribute":
			
			db_connect();
			$attribute = find_attribute_by_id($_POST['attributeId']);
			show_attribute($attribute);
			break;
			
		case "saveattribute":

			db_connect();
			
			// Update attribute
			if($READ_ONLY_MODE === FALSE) {
				$values = Array("name" => $_POST['name']);
				update_attribute($values, $_POST['attributeId']);
			}

			// Show attribute page			
			$attribute = find_attribute_by_id($_POST['attributeId']);
			show_attribute($attribute);
			break;
			
		case "addattribute":

			// Insert attribute		
			db_connect();
			$values = Array("name" => $_POST['name']);
			
			if($READ_ONLY_MODE === FALSE && insert_attribute($values) === TRUE) {
				
				// Show saved attribute on success
				$attribute = find_attribute_by_id(db_insert_id());
				show_attribute($attribute);
				
			} else {
				
				// Show error on failure
				show_attributes();
				
			}
			break;
			
		case "deleteattribute":
		
			db_connect();
			
			// Delete attribute	
			if($READ_ONLY_MODE === FALSE) {
				delete_attribute_by_id($_POST['attributeId']);
			}

			// Show list of attributes			
			show_attributes();
			break;
			
		case "moveattribute":
		
			db_connect();
			
			// Move attribute	
			if($READ_ONLY_MODE === FALSE) {
				move_attribute($_POST['attributeId'], $_POST['direction']);
			}

			// Show list of attributes			
			show_attributes();
			break;
			
		case "addvalue":

			db_connect();
			
			// Insert value
			if($READ_ONLY_MODE === FALSE) {
				$values = Array("attributeId" => $_POST['attributeId'], "value" => $_POST['value']);
				insert_value($values);
			}

			// Show attribute page
			$attribute = find_attribute_by_id($_POST['attributeId']);
			show_attribute($attribute);
			break;
			
		case "deletevalue":

			db_connect();
			
			// Delete value
			if($READ_ONLY_MODE === FALSE) {
				delete_value_by_id($_POST['valueId']);
			}

			// Show attribute page			
			$attribute = find_attribute_by_id($_POST['attributeId']);
			show_attribute($attribute);
			break;
			
		case "logout":
		
			// Kill session and force expire of session cookie on client
			$_SESSION = array();
			if(isset($_COOKIE[session_name()])) setcookie(session_name(), '', time()-7200, '/');
			session_destroy();

			// Redirect back to login page		
			relative_location('../login.php');
			exit();
			
	}
	
} else {

	// Display admin panel
	show_panel();

}

function show_back_button() {
?> 
<div class="bottomPageNav">
<form method="get" action=".">
<p>
<input type="submit" value="Back to Administration Panel" class="submit" />
</p>
</form>
</div>
<?php
}

?>