<?php
/****************************************************************************
 * DRBImageGallery
 * http://www.dbscripts.net/imagegallery/
 * 
 * Copyright (c) 2007-2009 Don Barnes 
 ****************************************************************************/
 
$base_url = "./";
require_once(dirname(__FILE__) . '/includes/utils.php');
require_once(dirname(__FILE__) . '/includes/db_utils.php');
require_once(dirname(__FILE__) . '/config.php');
require_once(dirname(__FILE__) . '/strings.php');

include_from_template('header.php');

// If user clicked continue, do install, otherwise display warning
if(isset($_POST['action']) && $_POST['action'] === 'install' ) {

	echo '<h2>Install</h2>';
	
	// Connect to database
	global $DB_HOST;
	echo "<p>Connecting to $DB_HOST...</p>";
	if(db_connect() === FALSE) {
		die("Error connecting to database: " . db_error());
	}

	// Create image table
	global $TABLE_IMAGE;
	global $MAX_IMAGE_FILENAME_LENGTH;
	global $MAX_IMAGE_NAME_LENGTH;
	global $MAX_IMAGE_DESCRIPTION_LENGTH;   
	$img_tablename = full_table_name($TABLE_IMAGE);
	echo "<p>Creating {$img_tablename} table...</p>";
	$ddl_stmt = <<<EOT
create table {$img_tablename} (
 imageId           int unsigned not null auto_increment,
 filename          varchar({$MAX_IMAGE_FILENAME_LENGTH}) not null,
 name              varchar({$MAX_IMAGE_NAME_LENGTH}) null,
 description       text null,
 addedDt		   datetime not null,
 primary key (imageId)
);
EOT;
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating {$img_tablename} table: " . db_error());
	}
	
	// Create index
	echo "<p>Creating index on {$img_tablename} table...</p>";
	$ddl_stmt = "create index idx_{$img_tablename}_file on {$img_tablename} (filename($MAX_IMAGE_FILENAME_LENGTH));";
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating index on {$img_tablename} table: " . db_error());
	}

	// Create index
	echo "<p>Creating index on {$img_tablename} table...</p>";
	$ddl_stmt = "create index idx_{$img_tablename}_add on {$img_tablename} (addedDt);";
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating index on {$img_tablename} table: " . db_error());
	}
	
	// Create attribute table
	global $TABLE_ATTRIBUTE;
	global $MAX_ATTRIBUTE_NAME_LENGTH;
	$attr_tablename = full_table_name($TABLE_ATTRIBUTE);
	echo "<p>Creating {$attr_tablename} table...</p>";
	$ddl_stmt = <<<EOT
create table {$attr_tablename} (
 attributeId       int unsigned not null auto_increment,
 name              varchar({$MAX_ATTRIBUTE_NAME_LENGTH}) not null,
 sequenceNum       int not null,
 addedDt		   datetime not null,
 primary key (attributeId)
);
EOT;
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating {$attr_tablename} table: " . db_error());
	}
	
	// Create attribute value table
	global $TABLE_ATTRIBUTE_VALUE;
	global $MAX_ATTRIBUTE_VALUE_LENGTH;
	$attrval_tablename = full_table_name($TABLE_ATTRIBUTE_VALUE);
	echo "<p>Creating {$attrval_tablename} table...</p>";
	$ddl_stmt = <<<EOT
create table {$attrval_tablename} (
 valueId           int unsigned not null auto_increment,
 attributeId       int unsigned not null,
 value             varchar({$MAX_ATTRIBUTE_VALUE_LENGTH}) not null,
 addedDt		   datetime not null,
 primary key (valueId),
 foreign key (attributeId) references {$attr_tablename}(attributeId)
);
EOT;
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating {$attrval_tablename} table: " . db_error());
	}
	
	// Create index
	echo "<p>Creating index on {$attrval_tablename} table...</p>";
	$ddl_stmt = "create index idx_{$attrval_tablename}_attributeId on {$attrval_tablename} (attributeId);";
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating index on {$attrval_tablename} table: " . db_error());
	}
	
	// Create image attribute value table
	global $TABLE_IMAGE_ATTRIBUTE_VALUE;
	$tablename = full_table_name($TABLE_IMAGE_ATTRIBUTE_VALUE);
	echo "<p>Creating {$tablename} table...</p>";
	$ddl_stmt = <<<EOT
create table {$tablename} (
 attributeId       int unsigned not null,
 valueId           int unsigned not null,
 imageId           int unsigned not null,
 addedDt		   datetime not null,
 primary key (attributeId, valueId, imageId),
 foreign key (attributeId) references {$attr_tablename}(attributeId),
 foreign key (valueId) references {$attrval_tablename}(valueId),
 foreign key (imageId) references {$img_tablename}(imageId)
);
EOT;
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating {$tablename} table: " . db_error());
	}

	// Create index
	echo "<p>Creating index on {$tablename} table...</p>";
	$ddl_stmt = "create index idx_{$tablename}_img on {$tablename} (imageId);";
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating index on {$tablename} table: " . db_error());
	}
	
	// Create index
	echo "<p>Creating index on {$tablename} table...</p>";
	$ddl_stmt = "create index idx_{$tablename}_attr on {$tablename} (attributeId);";
	if(db_execute($ddl_stmt) === FALSE) {
		die("Error creating index on {$tablename} table: " . db_error());
	}
	

?>
<p>
Congratulations, installation has completed. 
</p>
<p> 
<strong>You must delete install.php before using the system.</strong>
</p>
<p>  
After you have deleted install.php, you may access 
the <a href="admin/">administration panel</a>.  
</p>

<?php
	
} else if(isset($_POST['action']) && $_POST['action'] === 'uninstall' ) {
	$error_happened = FALSE;

	echo '<h2>Uninstall</h2>';

	// Connect to database
	global $DB_HOST;
	echo "<p>Connecting to $DB_HOST...</p>";
	if(db_connect() === FALSE) {
		die("Error connecting to database: " . db_error());
	}
	
	global $TABLE_IMAGE_ATTRIBUTE_VALUE;
	$tablename = full_table_name($TABLE_IMAGE_ATTRIBUTE_VALUE);
	echo "<p>Dropping {$tablename} table...</p>";
	if(db_execute("drop table {$tablename}") === FALSE) {
		echo "Error dropping table '{$tablename}': " . db_error();
		$error_happened = TRUE;
	} 
	
	global $TABLE_ATTRIBUTE_VALUE;
	$tablename = full_table_name($TABLE_ATTRIBUTE_VALUE);
	echo "<p>Dropping {$tablename} table...</p>";
	if(db_execute("drop table {$tablename}") === FALSE) {
		echo "Error dropping table '{$tablename}': " . db_error();
		$error_happened = TRUE;
	} 
	
	global $TABLE_ATTRIBUTE;
	$tablename = full_table_name($TABLE_ATTRIBUTE);
	echo "<p>Dropping {$tablename} table...</p>";
	if(db_execute("drop table {$tablename}") === FALSE) {
		echo "Error dropping table '{$tablename}': " . db_error();
		$error_happened = TRUE;
	}
	
	global $TABLE_IMAGE;
	$tablename = full_table_name($TABLE_IMAGE);
	echo "<p>Dropping {$tablename} table...</p>";
	if(db_execute("drop table {$tablename}") === FALSE) {
		echo "Error dropping table '{$tablename}': " . db_error();
		$error_happened = TRUE;
	} 

if($error_happened) {
?>
<p>
There were problems uninstalling. 
</p>
<?php
} else {
?>
<p>
Uninstallation has completed.  You will need to reinstall if you wish to use the system again in the future. 
</p>
<?php
}
?>
<p>
<a href="install.php">Go Back</a>
</p>
<?php
	
} else {

?>

<h2>Install</h2>

<p>
Please confirm that the following settings are correct.  
</p> 

<table>
<?php
// Database configuration
global $DB_HOST;
global $DB_USERNAME;
global $DB_PASSWORD;
global $DB_SCHEMA;
global $TABLE_PREFIX;

echo "<tr><td>Database server:</td><td>$DB_HOST</td></tr>\n";
echo "<tr><td>Database username:</td><td>$DB_USERNAME</td></tr>\n";
echo "<tr><td>Database password:</td><td>$DB_PASSWORD</td></tr>\n";
echo "<tr><td>Database schema:</td><td>$DB_SCHEMA</td></tr>\n";
echo "<tr><td>Table prefix:</td><td>$TABLE_PREFIX</td></tr>\n";
?>
</table>

<p>
If any of these settings are not correct, please edit the 
config.php file to reflect the correct settings.  
Otherwise, click continue to perform the install and 
create the required tables.
</p>

<form method="post" action="install.php">
<input type="hidden" name="action" value="install" />
<input type="submit" value="Continue with the Install" /> 
</form>

<p>
You may also choose to uninstall.  This will drop the required tables. 
<strong>If you choose to uninstall, all data will be lost!</strong>
</p>

<form method="POST" action="install.php">
<input type="hidden" name="action" value="uninstall" />
<input type="submit" value="Uninstall" /> 
</form>

<?php
}

include_from_template('footer.php');
?>